@@ -13,7 +13,20 @@ class Expander(object):
        base:typing.List[str],
        includes:typing.List[str]=None,
        excludes:typing.List[str]=None,
+       header:str="",
+       trailer:str="",
        indent:int=4):
+    """
+    Parameters
+    ----------
+    kwargs: keyword arguments to document
+    base: base list of arguments
+    includes: additional arguments to include
+    excludes: arguments to exclude
+    header: header to print a beginning
+    trailer to print at the end
+    indent: spaces of indentiation
+    """
     self.kwarg_dct = {k.name: k for k in kwargs}
     self.base = base
     self._indent = indent
@@ -25,6 +38,13 @@ class Expander(object):
     self.excludes = excludes
     self.keywords = set(base).difference(excludes)
     self.keywords = list(self.keywords.union(includes))
+    self.header = header
+    self.trailer = trailer
+
+  def _indentText(self, text, indent_str):
+    strings = text.split("\n")
+    textList= ["%s%s" % (indent_str, s) for s in strings]
+    return '\n'.join(textList)
 
   def __call__(self, func:typing.Callable):
     string = func.__doc__
@@ -37,15 +57,19 @@ class Expander(object):
       if string[pos - idx] != " ":
         indent = idx - 1
         break
+    indent_str = self._getIndentStr(indent)
     # Construct the expansion
-    expansion = ""
+    if len(self.header) > 0:
+      expansion = self._indentText(self.header, indent_str)
+    else:
+      expansion = ""
     keywords = list(self.keywords)
     keywords.sort()
     for idx, keyword in enumerate(keywords):
       self.kwarg_dct[keyword].setIndent(self._indent)
       expansion += str(self.kwarg_dct[keyword])
+    expansion += self._indentText(self.trailer, indent_str)
     # Replace the docstring
-    indent_str = self._getIndentStr(indent)
     replace_str = "%s%s"  % (indent_str, cn.EXPAND)
     func.__doc__ = string.replace(replace_str, expansion)
     return func
